@@ -11,7 +11,6 @@ import json
 import time
 
 import requests
-# from ys_service.queue_service.context import Context
 SAVE_TO_LOG_CENTER_URL = "http://192.168.0.212:8081/log/save"
 # from ys_service import SAVE_TO_LOG_CENTER_URL
 from datetime import datetime, timezone, timedelta
@@ -28,7 +27,7 @@ def get_time():
     return now_zone8.isoformat()
 
 
-def send_to_log_center(context, project="", module="", user="", level="", return_msg="", **kwargs):
+def send_to_log_center(context, project, module, user, level, return_msg, **kwargs):
     """
     send msg to log_center
     :param context:
@@ -43,9 +42,9 @@ def send_to_log_center(context, project="", module="", user="", level="", return
 
     # 数据组成
     msg_data = {
-        "返回数据": return_msg,
-        "队列名称": context.queue.queue_name,
-        "传入数据:": context.text
+        "a返回数据": return_msg,
+        "b传入数据:": context.get_json(),
+        "c队列名称": context.queue.queue_name
     }
     # 请求数据
     request_data = {
