@@ -22,7 +22,8 @@ class Queue(object):
             func: Callable,
             auto_ack: bool,
             prefetch: int,
-            service
+            service,
+            **config_map,
     ):
         """
         :param queue_name: 队列名
@@ -36,3 +37,4 @@ class Queue(object):
         self.auto_ack = auto_ack
         self.prefetch = prefetch
         self.service = service
+        self.consumer_tag = config_map.get("consumer_tag", None)
